<?php
if (!defined('ABSPATH')) {
    exit;
}

//////////////////////////////////////////////////////////////////////
// Plugin activation in Wordpress
//////////////////////////////////////////////////////////////////////

function mcisps_activation()
{
    // Set default values in DB
    mcisps_set_default_values();

    update_option('mcisps_version', MCISPS_VERSION);
}

register_activation_hook(__FILE__, 'mcisps_activation');

//////////////////////////////////////////////////////////////////////
// Plugin deactivation in Wordpress if WooCommerce is not active
//////////////////////////////////////////////////////////////////////

function mcisps_check_woocommerce()
{
    // Check if WooCommerce is active and if not, deactivate the plugin and show an error message in the admin panel (if the user is logged in)
    // If WooCommerce is active, the plugin will check if simple_product_samples is active and deactivate it if it is
    if (is_admin()) {
        if (!in_array('woocommerce/woocommerce.php', apply_filters('active_plugins', get_option('active_plugins')))) {
            add_action('admin_notices', 'mcisps_wc_not_active_message');

            // Check if simple_product_sample is active and deactivate the plugin
            if (is_plugin_active(plugin_basename(dirname(__FILE__, 2)) . '/simple-product-sample.php')) {
                deactivate_plugins(plugin_basename(dirname(__FILE__, 2)) . '/simple-product-sample.php');
            }

            return;
        }
    }
}

add_action('admin_init', 'mcisps_check_woocommerce');

//////////////////////////////////////////////////////////////////////
// Compare version and execute mcisps_init if version is different
//////////////////////////////////////////////////////////////////////

function mcisps_check_version()
{
    if (MCISPS_VERSION != get_option('mcisps_version')) {
        mcisps_activation();
    }
}
add_action('plugins_loaded', 'mcisps_check_version');
